exceptions

exceptions

PlanetarPy exceptions.

Classes

Name Description
Error Base class for exceptions in this module.
GeoTransformNotSetError Exception raised when a GeoTransform is not set.
ProjectionNotSetError Exception raised when a projection is not set.
SomethingNotSetError Exception raised for errors in the input of transformations.
SpicerError Base class for exceptions in this module.

Error

exceptions.Error()

[source]

Base class for exceptions in this module.

GeoTransformNotSetError

exceptions.GeoTransformNotSetError(where)

[source]

Exception raised when a GeoTransform is not set.

ProjectionNotSetError

exceptions.ProjectionNotSetError(where)

[source]

Exception raised when a projection is not set.

SomethingNotSetError

exceptions.SomethingNotSetError(where, what)

[source]

Exception raised for errors in the input of transformations.

Parameters

Name Type Description Default
where Where something is missing. required
what What is missing. required

SpicerError

exceptions.SpicerError()

[source]

Base class for exceptions in this module.